@@ -2,7 +2,7 @@ package MogileFS::Server;
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = "2.07";
+$VERSION = "2.08";
 
 use IO::Socket;
 use Symbol;
@@ -31,7 +31,7 @@ use MogileFS::Worker::Delete;
 use MogileFS::Worker::Replicate;
 use MogileFS::Worker::Reaper;
 use MogileFS::Worker::Monitor;
-use MogileFS::Worker::Checker;
+use MogileFS::Worker::Fsck;
 
 use MogileFS::HTTPFile;
 use MogileFS::Class;
@@ -73,7 +73,7 @@ sub run {
     MogileFS::ProcManager->set_min_workers('replicate'   => MogileFS->config('replicate_jobs'));
     MogileFS::ProcManager->set_min_workers('reaper'      => MogileFS->config('reaper_jobs'));
     MogileFS::ProcManager->set_min_workers('monitor'     => MogileFS->config('monitor_jobs'));
-    MogileFS::ProcManager->set_min_workers('checker'     => MogileFS->config('checker_jobs'));
+    MogileFS::ProcManager->set_min_workers('fsck'        => 1);
 
     # open up our log
     Sys::Syslog::openlog('mogilefsd', 'pid', 'daemon');
