@@ -2,16 +2,22 @@ package MogileFS::Util;
 use strict;
 use Carp qw(croak);
 use Time::HiRes;
+use MogileFS::Exception;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
-                    error debug fatal daemonize weighted_list every dbcheck
-                    wait_for_readability wait_for_writeability
+                    error debug fatal daemonize weighted_list every
+                    wait_for_readability wait_for_writeability throw error_code
                     );
 
 sub every {
     my ($delay, $code) = @_;
+    my ($worker, $psock_fd);
+    if ($worker = MogileFS::ProcManager->is_child) {
+        $psock_fd = $worker->psock_fd;
+    }
+  CODERUN:
     while (1) {
         my $start = Time::HiRes::time();
         my $explicit_sleep = undef;
@@ -23,12 +29,29 @@ sub every {
             });
         }
 
-        my $took = Time::HiRes::time() - $start;
-        my $sleep_for = $delay - $took;
-        if (defined $explicit_sleep) {
-            Time::HiRes::sleep($explicit_sleep);
-        } else {
-            Time::HiRes::sleep($sleep_for) if $sleep_for > 0;
+        my $now = Time::HiRes::time();
+        my $took = $now - $start;
+        my $sleep_for = defined $explicit_sleep ? $explicit_sleep : ($delay - $took);
+        next unless $sleep_for > 0;
+
+        # simple case, not in a child process (this never happens currently)
+        unless ($psock_fd) {
+            Time::HiRes::sleep($sleep_for);
+            next;
+        }
+
+        while ($sleep_for > 0) {
+            my $last_time_pre_sleep = $now;
+            $worker->forget_woken_up;
+            if (wait_for_readability($psock_fd, $sleep_for)) {
+                # TODO: uncomment this and watch an idle server and how many wakeups.  could optimize.
+                #local $Mgd::POST_SLEEP_DEBUG = 1;
+                #warn "WOKEN UP FROM SLEEP in $worker [$$]\n";
+                $worker->read_from_parent;
+                next CODERUN if $worker->was_woken_up;
+            }
+            $now = Time::HiRes::time();
+            $sleep_for -= ($now - $last_time_pre_sleep);
         }
     }
 }
@@ -50,13 +73,16 @@ sub error {
     my ($errmsg) = @_;
     $last_error = $errmsg;
     if (my $worker = MogileFS::ProcManager->is_child) {
-        $worker->send_to_parent("error $errmsg");
+        my $msg = "error $errmsg";
+        $msg =~ s/\s+$//;
+        $worker->send_to_parent($msg);
     } else {
         MogileFS::ProcManager->NoteError(\$errmsg);
         Mgd::log('debug', $errmsg);
     }
     return 0;
 }
+
 sub last_error {
     return $last_error;
 }
@@ -67,6 +93,17 @@ sub fatal {
     die $errmsg;
 }
 
+sub throw {
+    my ($errcode) = @_;
+    MogileFS::Exception->new($errcode)->throw;
+}
+
+sub error_code {
+    my ($ex) = @_;
+    return "" unless UNIVERSAL::isa($ex, "MogileFS::Exception");
+    return $ex->code;
+}
+
 sub daemonize {
     my($pid, $sess_id, $i);
 
@@ -143,21 +180,13 @@ sub weighted_list {
     return @ret;
 }
 
-sub dbcheck {
-    my ($dbh, $errmsg) = @_;
-    return unless $dbh->err;
-    $errmsg .= ": " . $dbh->err . ": " . $dbh->errstr;
-    error($errmsg);  # propogate to parent for listeners
-    die $errmsg;
-}
-
 # given a file descriptor number and a timeout, wait for that descriptor to
 # become readable; returns 0 or 1 on if it did or not
 sub wait_for_readability {
     my ($fileno, $timeout) = @_;
     return 0 unless $fileno && $timeout >= 0;
 
-    my $rin;
+    my $rin = '';
     vec($rin, $fileno, 1) = 1;
     my $nfound = select($rin, undef, undef, $timeout);
 
@@ -169,7 +198,7 @@ sub wait_for_writeability {
     my ($fileno, $timeout) = @_;
     return 0 unless $fileno && $timeout;
 
-    my $rout;
+    my $rout = '';
     vec($rout, $fileno, 1) = 1;
     my $nfound = select(undef, $rout, undef, $timeout);
 
